summaryrefslogtreecommitdiffstats
path: root/src/server/Buffer.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/server/Buffer.hpp')
-rw-r--r--src/server/Buffer.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/server/Buffer.hpp b/src/server/Buffer.hpp
index e22e89e6..7593900e 100644
--- a/src/server/Buffer.hpp
+++ b/src/server/Buffer.hpp
@@ -73,11 +73,11 @@ public:
/** Set the buffer type and optional value type for this buffer.
*
* @param get Called to get auxiliary buffers if necessary.
* @param type Type of buffer.
* @param value_type Type of values in buffer if applicable (for sequences).
*/
- void set_type(GetFn get, LV2_URID type, LV2_URID value_type);
+ void set_type(GetFn get_func, LV2_URID type, LV2_URID value_type);
inline bool is_audio() const {
return _type == _factory.uris().atom_Sound;
@@ -73,11 +73,11 @@ public:
/** Set the buffer type and optional value type for this buffer.
*
- * @param get Called to get auxiliary buffers if necessary.
+ * @param get_func Called to get auxiliary buffers if necessary.
* @param type Type of buffer.
* @param value_type Type of values in buffer if applicable (for sequences).